# Neural Network Visualizer

[![PyPI version](https://img.shields.io/pypi/v/neuralnet-visualize?logo=pypi&logoColor=yellow&style=plastic)](https://pypi.org/project/neuralnet-visualize/)
[![PyPI downloads](https://img.shields.io/pypi/dm/neuralnet-visualize?style=plastic)](https://pypistats.org/packages/neuralnet-visualize)
[![License](https://img.shields.io/badge/License-Apache%202.0-brightgreen.svg)](https://opensource.org/licenses/Apache-2.0)
[![Py version](https://img.shields.io/pypi/pyversions/neuralnet-visualize?logo=python&logoColor=yellow?style=plastic)](https://pypi.org/project/neuralnet-visualize/)
[![Wheel](https://img.shields.io/pypi/wheel/neuralnet-visualize)](https://pypi.org/project/neuralnet-visualize/)
![Code Size](https://img.shields.io/github/languages/code-size/AnuragAnalog/nn_visualize?logo=github)
![Repo Size](https://img.shields.io/github/repo-size/AnuragAnalog/nn_visualize?logo=github&style=plastic)
![Contributors](https://img.shields.io/github/contributors/AnuragAnalog/nn_visualize?style=plastic)
![Commit Activity](https://img.shields.io/github/commit-activity/w/AnuragAnalog/nn_visualize?style=plastic)

## What is NN_Visualize?

A module which creates a neural network image with the given architecture. It's a handy tool to see how your network is built as compared to a model summary

## Installation

For installation you can follow the instructions [here](./INSTALLATION.md)

## Examples
Some of the examples can be found [here](./examples)

The docstring style which I have followed is [numpydoc](https://numpydoc.readthedocs.io/en/latest/)

## Network Visualization
![A demo](./neuralnet.png)

## Future Works

- [x] Add Convolutional layers, Maxpooling, Flatten layers
- [ ] Add Sequence model layers
- [ ] Directly from the pickle files
- [ ] Specific colors for activation functions
- [ ] Directly convert from pytorch models